function X = internal_mtimesadd(X, W, B)
% This function is undocumented and will change in a future release.

%   X = internal_mtimesadd(X, W, B)
%   Compute the linear matrix multiplication and addition Y = W*X + B.
%
%   Inputs:
%     X               numeric array
%     W               numeric array
%     B               numeric array.
%
%   Outputs:
%     Y               numeric array

%   Copyright 2021 The MathWorks, Inc.

X = W*X + B;

end
